==> swfdec0.6_0.6.8.orig.tar.gz: swfdec-0.6.8/swfdec/swfdec_filter.h <==
/* Swfdec
 * Copyright (C) 2007 Benjamin Otte <otte@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef _SWFDEC_FILTER_H_
#define _SWFDEC_FILTER_H_

#include <swfdec/swfdec.h>
#include <swfdec/swfdec_as_object.h>
#include <swfdec/swfdec_bits.h>
#include <swfdec/swfdec_types.h>

G_BEGIN_DECLS

typedef struct _SwfdecFilterClass SwfdecFilterClass;

#define SWFDEC_TYPE_FILTER                    (swfdec_filter_get_type())
#define SWFDEC_IS_FILTER(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SWFDEC_TYPE_FILTER))
#define SWFDEC_IS_FILTER_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), SWFDEC_TYPE_FILTER))
#define SWFDEC_FILTER(obj)                    (G_TYPE_CHECK_INSTANCE_CAST ((obj), SWFDEC_TYPE_FILTER, SwfdecFilter))
#define SWFDEC_FILTER_CLASS(klass)            (G_TYPE_CHECK_CLASS_CAST ((klass), SWFDEC_TYPE_FILTER, SwfdecFilterClass))
#define SWFDEC_FILTER_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), SWFDEC_TYPE_FILTER, SwfdecFilterClass))

struct _SwfdecFilter {
  SwfdecAsObject	object;
};

struct _SwfdecFilterClass {
  SwfdecAsObjectClass	object_class;

  SwfdecFilter *	(* clone)		(SwfdecFilter *		filter);
  cairo_pattern_t *	(* apply)		(SwfdecFilter *		filter,
						 cairo_pattern_t *	pattern);
};

GType			swfdec_filter_get_type	(void);

cairo_pattern_t *	swfdec_filter_apply	(SwfdecFilter *		filter,
						 cairo_pattern_t *	pattern);
GSList *		swfdec_filter_parse	(SwfdecPlayer *		player,
						 SwfdecBits *		bits);


G_END_DECLS
#endif

==> swfdec0.8_0.8.4.orig.tar.gz: swfdec-0.8.4/swfdec/swfdec_filter.h <==
/* Swfdec
 * Copyright (C) 2007 Benjamin Otte <otte@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef _SWFDEC_FILTER_H_
#define _SWFDEC_FILTER_H_

#include <swfdec/swfdec.h>
#include <swfdec/swfdec_as_object.h>
#include <swfdec/swfdec_bits.h>
#include <swfdec/swfdec_types.h>

G_BEGIN_DECLS

typedef struct _SwfdecFilterClass SwfdecFilterClass;

#define SWFDEC_TYPE_FILTER                    (swfdec_filter_get_type())
#define SWFDEC_IS_FILTER(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SWFDEC_TYPE_FILTER))
#define SWFDEC_IS_FILTER_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), SWFDEC_TYPE_FILTER))
#define SWFDEC_FILTER(obj)                    (G_TYPE_CHECK_INSTANCE_CAST ((obj), SWFDEC_TYPE_FILTER, SwfdecFilter))
#define SWFDEC_FILTER_CLASS(klass)            (G_TYPE_CHECK_CLASS_CAST ((klass), SWFDEC_TYPE_FILTER, SwfdecFilterClass))
#define SWFDEC_FILTER_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), SWFDEC_TYPE_FILTER, SwfdecFilterClass))

struct _SwfdecFilter {
  SwfdecAsObject	object;
};

struct _SwfdecFilterClass {
  SwfdecAsObjectClass	object_class;

  SwfdecFilter *	(* clone)		(SwfdecFilter *		filter);
  cairo_pattern_t *	(* apply)		(SwfdecFilter *		filter,
						 cairo_pattern_t *	pattern);
};

GType			swfdec_filter_get_type	(void);

cairo_pattern_t *	swfdec_filter_apply	(SwfdecFilter *		filter,
						 cairo_pattern_t *	pattern);
GSList *		swfdec_filter_parse	(SwfdecBits *		bits);


G_END_DECLS
#endif
